@@ -1,11 +1,11 @@
 import collections
 import copy
 import logging
-import random
 import time
+import random
 
-import monasca_agent.common.keystone as keystone
 import monascaclient.client
+import monasca_agent.common.keystone as keystone
 
 log = logging.getLogger(__name__)
 
@@ -22,7 +22,9 @@ class MonascaAPI(object):
     MAX_BACKOFF = 60   # seconds
 
     def __init__(self, config):
-        """Initialize Mon api client connection."""
+        """
+        Initialize Mon api client connection.
+        """
         self.config = config
         self.url = config['url']
         self.api_version = '2_0'
@@ -33,7 +35,6 @@ class MonascaAPI(object):
         self.max_buffer_size = int(config['max_buffer_size'])
         self.backlog_send_rate = int(config['backlog_send_rate'])
         self.message_queue = collections.deque(maxlen=self.max_buffer_size)
-        self.write_timeout = int(config['write_timeout'])
         # 'amplifier' is completely optional and may not exist in the config
         try:
             self.amplifier = int(config['amplifier'])
@@ -103,6 +104,8 @@ class MonascaAPI(object):
         for measurement in measurements:
             m_dict = measurement.__dict__
             m_dict['timestamp'] *= 1000
+            if m_dict['value_meta'] is None:
+                del m_dict['value_meta']
             delegated_tenant = m_dict.pop('delegated_tenant')
             if delegated_tenant not in tenant_group:
                 tenant_group[delegated_tenant] = []
@@ -117,12 +120,14 @@ class MonascaAPI(object):
         token = self.keystone.get_token()
         if token:
             # Create the client.
-            kwargs = self.keystone.get_credential_args()
-            kwargs['token'] = token
+            kwargs = {
+                'token': token
+            }
+
             if not self.url:
                 self.url = self.keystone.get_monasca_url()
 
-            return monascaclient.client.Client(self.api_version, self.url, write_timeout=self.write_timeout, **kwargs)
+            return monascaclient.client.Client(self.api_version, self.url, **kwargs)
 
         return None
 
@@ -146,13 +151,13 @@ class MonascaAPI(object):
                 self._failure_reason = 'Invalid token detected. Waiting to get new token from Keystone'
                 wait_time = random.randint(MonascaAPI.MIN_BACKOFF, MonascaAPI.MAX_BACKOFF + 1)
                 self._resume_time = time.time() + wait_time
-                log.info("Invalid token detected. Waiting %d seconds before getting new token.", wait_time)
+                log.error("Invalid token detected. Waiting %d seconds before getting new token.", wait_time)
             else:
-                log.error("Error sending message to monasca-api. Error is {0}."
+                log.debug("Error sending message to monasca-api. Error is {0}."
                           .format(str(ex.message)))
                 self._failure_reason = 'Error sending message to the Monasca API: {0}'.format(str(ex.message))
         except Exception as ex:
-            log.error("Error sending message to Monasca API. Error is {0}."
+            log.debug("Error sending message to Monasca API. Error is {0}."
                       .format(str(ex.message)))
             self._failure_reason = 'The Monasca API is DOWN or unreachable'
 
