@@ -3,25 +3,17 @@ import logging
 import select
 import socket
 
-import monasca_agent.common.metrics as metrics_pkg
-
 log = logging.getLogger(__name__)
 
 
 UDP_SOCKET_TIMEOUT = 5
 
-metric_class = {
-    'g': metrics_pkg.Gauge,
-    'c': metrics_pkg.Counter,
-    'h': metrics_pkg.Histogram,
-    'ms': metrics_pkg.Histogram,
-    's': metrics_pkg.Set,
-    'r': metrics_pkg.Rate,
-}
-
 
 class Server(object):
-    """A statsd udp server."""
+
+    """
+    A statsd udp server.
+    """
 
     def __init__(self, aggregator, host, port, forward_to_host=None, forward_to_port=None):
         self.host = host
@@ -156,10 +148,10 @@ class Server(object):
                 name, value, mtype, dimensions, sample_rate = self._parse_metric_packet(packet)
 
                 self.aggregator.submit_metric(
-                    name, value, metric_class[mtype], dimensions=dimensions, sample_rate=sample_rate)
+                    name, value, mtype, dimensions=dimensions, sample_rate=sample_rate)
 
     def start(self):
-        """Run the server."""
+        """ Run the server. """
         # Bind to the UDP socket.
         # IPv4 only
         open_socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
