@@ -67,7 +67,7 @@ def main(argv=None):
                                               "metrics (cpu, disk, load, memory, network).",
                         action="store_true", default=False)
     parser.add_argument('-d', '--detection_plugins', nargs='*',
-                        help="Skip base config and service setup and only configure the this space separated list. " +
+                        help="Skip base config and service setup and only configure this space separated list. " +
                              "This assumes the base config has already run.")
     parser.add_argument('-a', '--detection_args', help="A string of arguments that will be passed to detection " +
                                                        "plugins. Only certain detection plugins use arguments.")
@@ -80,9 +80,10 @@ def main(argv=None):
                         default=False)
     parser.add_argument('--config_dir', help="Configuration directory", default='/etc/monasca/agent')
     parser.add_argument('--log_dir', help="monasca-agent log directory", default='/var/log/monasca/agent')
-    parser.add_argument('--log_level', help="monasca-agent logging level (ERROR, WARNING, INFO, DEBUG)", required=False, default='INFO')
-    parser.add_argument(
-        '--template_dir', help="Alternative template directory", default=os.path.join(PREFIX_DIR, 'share/monasca/agent'))
+    parser.add_argument('--log_level', help="monasca-agent logging level (ERROR, WARNING, INFO, DEBUG)", required=False,
+                        default='WARN')
+    parser.add_argument( '--template_dir', help="Alternative template directory",
+                         default=os.path.join(PREFIX_DIR, 'share/monasca/agent'))
     parser.add_argument('--overwrite',
                         help="Overwrite existing plugin configuration. " +
                              "The default is to merge. agent.yaml is always overwritten.",
